@@ -1008,7 +1008,7 @@ def interpret_items(schemas, raw_items, db_model=None):
                     raw_to_block.append((len(blocks) - 1, 0))
             elif item_type == TYPE_DIRECTIVE:
                 command = get_command(value_obj)
-                appended_schema_blocks_index = False
+                appended_directive_blocks_index = False
                 if command == '%' or command == '' or command is None:
                     # Comment
                     pass
@@ -1022,7 +1022,7 @@ def interpret_items(schemas, raw_items, db_model=None):
                     schemas[name] = current_schema = []
                     # Schema block should also be considered when calculating the focus index
                     raw_to_block.append((len(blocks) - 1 + len(current_schema_ids), 0))
-                    appended_schema_blocks_index = True
+                    appended_directive_blocks_index = True
                 elif command == 'addschema':
                     # Add to schema
                     if current_schema is None:
@@ -1054,12 +1054,12 @@ def interpret_items(schemas, raw_items, db_model=None):
                         )
                         .data
                     )
-
+                    appended_directive_blocks_index = True
                     raw_to_block.append((len(blocks) - 1, 0))
                 else:
                     raise UsageError("unknown directive `%s`" % command)
-                # Add a placeholder for other cmds
-                if not appended_schema_blocks_index:
+                # Add an empty item placeholder for other directives, since they do not represent substantial items
+                if not appended_directive_blocks_index:
                     raw_to_block.append(None)
             else:
                 raise RuntimeError('Unknown worksheet item type: %s' % item_type)
