@@ -36,6 +36,11 @@ def main():
     parser.add_argument(
         '--sleep-time', help='Number of seconds to wait between checks', default=5, type=int
     )
+    parser.add_argument(
+        '--restart-after-seconds',
+        type=int,
+        help='Restart the worker manager after this many seconds have passed since launch',
+    )
     parser.add_argument(
         '--once',
         help='Just run once and exit instead of looping (for debugging)',
